@@ -7,8 +7,8 @@ import torch.nn as nn
 from gym.spaces import Box
 from gym.spaces import Discrete
 
-import raylab.pytorch.nn as nnx
-import raylab.pytorch.nn.distributions as ptd
+import raylab.torch.nn as nnx
+import raylab.torch.nn.distributions as ptd
 from raylab.policy.modules.networks.mlp import StateMLP
 
 
@@ -155,15 +155,11 @@ class MLPContinuousPolicy(MLPStochasticPolicy):
         input_dependent_scale: bool,
     ):
         def params_fn(out_features):
-            params_mod = nnx.NormalParams(
+            return nnx.PolicyNormalParams(
                 out_features,
                 action_space.shape[0],
                 input_dependent_scale=input_dependent_scale,
-                bound_parameters=False,
             )
-            params_mod.max_logvar.fill_(2)
-            params_mod.min_logvar.fill_(-20)
-            return params_mod
 
         dist = ptd.TransformedDistribution(
             ptd.Independent(ptd.Normal(), reinterpreted_batch_ndims=1),
