@@ -21,7 +21,7 @@ from ray.tune.logger import pretty_print
 from torch import Tensor
 
 from raylab.agents.options import RaylabOptions
-from raylab.pytorch.utils import convert_to_tensor
+from raylab.torch.utils import convert_to_tensor
 from raylab.utils.annotations import StatDict
 from raylab.utils.annotations import TensorDict
 from raylab.utils.dictionaries import deep_merge
